@@ -41,7 +41,7 @@ head(verbAggrProperties)
 ## -----------------------------------------------------------------------------
 get_booklets(db)
 head(get_items(db))
-get_persons(db) %>% 
+get_persons(db) |> 
   glimpse()
 
 ## -----------------------------------------------------------------------------
